package com.cirs.biz.service;

import java.util.List;
import com.cirs.biz.domain.TVerificationScoretask;
import com.cirs.biz.domain.TVerificationScoretaskDetail;

/**
 * 打分算法验证任务Service接口
 * 
 * @author allen
 * @date 2023-12-10
 */
public interface ITVerificationScoretaskService 
{
    /**
     * 查询打分算法验证任务
     * 
     * @param id 打分算法验证任务主键
     * @return 打分算法验证任务
     */
    public TVerificationScoretask selectTVerificationScoretaskById(Long id);

    /**
     * 查询打分算法验证任务列表
     * 
     * @param tVerificationScoretask 打分算法验证任务
     * @return 打分算法验证任务集合
     */
    public List<TVerificationScoretask> selectTVerificationScoretaskList(TVerificationScoretask tVerificationScoretask);

    /**
     * 新增打分算法验证任务
     * 
     * @param tVerificationScoretask 打分算法验证任务
     * @return 结果
     */
    public int insertTVerificationScoretask(TVerificationScoretask tVerificationScoretask);

    /**
     * 修改打分算法验证任务
     * 
     * @param tVerificationScoretask 打分算法验证任务
     * @return 结果
     */
    public int updateTVerificationScoretask(TVerificationScoretask tVerificationScoretask);

    /**
     * 批量删除打分算法验证任务
     * 
     * @param ids 需要删除的打分算法验证任务主键集合
     * @return 结果
     */
    public int deleteTVerificationScoretaskByIds(Long[] ids);

    /**
     * 删除打分算法验证任务信息
     * 
     * @param id 打分算法验证任务主键
     * @return 结果
     */
    public int deleteTVerificationScoretaskById(Long id);


}
